Index: src/handles.h |
diff --git a/src/handles.h b/src/handles.h |
index 13c6dd67f71e4aca1c7b59e6057f143a29347fd3..9bb3b1f1d5cac7fa2e7e13e896b41e557e07c0eb 100644 |
--- a/src/handles.h |
+++ b/src/handles.h |
@@ -264,9 +264,13 @@ Handle<Object> GetPrototype(Handle<Object> obj); |
Handle<Object> SetPrototype(Handle<JSObject> obj, Handle<Object> value); |
// Return the object's hidden properties object. If the object has no hidden |
-// properties and create_if_needed is true, then a new hidden property object |
-// will be allocated. Otherwise the Heap::undefined_value is returned. |
-Handle<Object> GetHiddenProperties(Handle<JSObject> obj, bool create_if_needed); |
+// properties and HiddenPropertiesFlag::ALLOW_CREATION is passed, then a new |
+// hidden property object will be allocated. Otherwise Heap::undefined_value |
+// is returned. |
+Handle<Object> GetHiddenProperties(Handle<JSObject> obj, |
+ JSObject::HiddenPropertiesFlag flag); |
+ |
+int GetIdentityHash(Handle<JSObject> obj); |
Handle<Object> DeleteElement(Handle<JSObject> obj, uint32_t index); |
Handle<Object> DeleteProperty(Handle<JSObject> obj, Handle<String> prop); |
@@ -343,6 +347,10 @@ Handle<Object> SetPrototype(Handle<JSFunction> function, |
Handle<Object> PreventExtensions(Handle<JSObject> object); |
+Handle<ObjectHashTable> PutIntoObjectHashTable(Handle<ObjectHashTable> table, |
+ Handle<JSObject> key, |
+ Handle<Object> value); |
+ |
// Does lazy compilation of the given function. Returns true on success and |
// false if the compilation resulted in a stack overflow. |
enum ClearExceptionFlag { KEEP_EXCEPTION, CLEAR_EXCEPTION }; |